@@ -5,12 +5,13 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 from uti.confi import Var
 
 def start() -> scoped_session:
-    engine = create_engine(Var.DB_URI)
+    dbi_uri=Var.DB_URL
+    dbi_uri="postgresql://"+dbi_uri[dbi_uri.index("//")+1:len(dbi_uri)]
+    engine = create_engine()
     BASE.metadata.bind = engine
     BASE.metadata.create_all(engine)
     return scoped_session(sessionmaker(bind=engine, autoflush=False))
 
-
 try:
     BASE = declarative_base()
     SESSION = start()
